@@ -1,7 +1,8 @@
 import pandas as pd
 from sqlalchemy import create_engine
 import datetime
-from pysin import prescription_generator
+from random import randint
+from pysin import prescription_generator, cr_generator
 from tqdm import tqdm
 
 from pysin.mimic.database_generator import DataBaseRandomGenerator
@@ -102,7 +103,8 @@ def generate_database():
         "--locale",
         default="fr_FR",
         type=str,
-        help="The locale to use when generating data",  # see available locales here (https://faker.readthedocs.io/en/master/locales.html)
+        help="The locale to use when generating data",
+        # see available locales here (https://faker.readthedocs.io/en/master/locales.html)
     )
 
     args = parser.parse_args()
@@ -162,7 +164,7 @@ def generate_database():
             ("row_id", Attribute(DigitIDAttr)),
             (
                 "careunit",
-                Attribute(FieldAttr, possible_values=possible_values["services"]["curr_service"],),
+                Attribute(FieldAttr, possible_values=possible_values["services"]["curr_service"], ),
             ),
         ],
         "caregivers": [
@@ -208,7 +210,7 @@ def generate_database():
                         RelativeFloatAttr, min_val=float(min_val), max_val=float(max_val),
                     )
                 elif attr_type == "bool":
-                    curr_attributes[attr] = Attribute(BoolAttr, proba_true=float(attr_params),)
+                    curr_attributes[attr] = Attribute(BoolAttr, proba_true=float(attr_params), )
                 elif attr_type == "double_digit_id":
                     curr_attributes[attr] = Attribute(DoubleDigitIDAttr, length=int(attr_params))
                 elif attr_type == "composed_digit_id-":
@@ -247,7 +249,7 @@ def generate_database():
 
     relations = {
         "hadm_id": {
-            "parents": [("admissions", "hadm_id"),],
+            "parents": [("admissions", "hadm_id"), ],
             "children": [
                 ("chartevents", "hadm_id", (1, 2)),
                 # ('datetimeevents', 'hadm_id', (1, 2)),
@@ -264,7 +266,7 @@ def generate_database():
             ],
         },
         "subject_id": {
-            "parents": [("patients", "subject_id"),],
+            "parents": [("patients", "subject_id"), ],
             "children": [
                 ("admissions", "subject_id", (1, 2)),
                 ("chartevents", "subject_id", (1, 2)),
@@ -282,7 +284,7 @@ def generate_database():
             ],
         },
         "cgid": {
-            "parents": [("caregivers", "cgid"),],
+            "parents": [("caregivers", "cgid"), ],
             "children": [
                 ("chartevents", "cgid", (1, 2)),
                 # ('datetimeevents', 'cgid', (1, 2)),
@@ -290,7 +292,7 @@ def generate_database():
             ],
         },
         "icustay_id": {
-            "parents": [("icustays", "icustay_id"),],
+            "parents": [("icustays", "icustay_id"), ],
             "children": [
                 ("chartevents", "icustay_id", (0, 2)),
                 # ('datetimeevents', 'icustay_id', (1, 2)),
@@ -299,7 +301,7 @@ def generate_database():
             ],
         },
         "itemid": {
-            "parents": [("d_items", "itemid"),],
+            "parents": [("d_items", "itemid"), ],
             "children": [
                 ("chartevents", "itemid", (1, 2)),
                 # ('datetimeevents', 'itemid', (1, 2)),
@@ -310,12 +312,12 @@ def generate_database():
             ],
         },
         "icd9_code_diagnoses": {
-            "parents": [("d_icd_diagnoses", "icd9_code"),],
-            "children": [("diagnoses_icd", "icd9_code", (1, 2)),],
+            "parents": [("d_icd_diagnoses", "icd9_code"), ],
+            "children": [("diagnoses_icd", "icd9_code", (1, 2)), ],
         },
         "icd9_code_procedures": {
-            "parents": [("d_icd_procedures", "icd9_code"),],
-            "children": [("procedures_icd", "icd9_code", (1, 2)),],
+            "parents": [("d_icd_procedures", "icd9_code"), ],
+            "children": [("procedures_icd", "icd9_code", (1, 2)), ],
         },
         "service": {
             "parents": [("hospit_services", "careunit")],
@@ -358,7 +360,8 @@ def generate_pdf():
         "--locale",
         default="fr_FR",
         type=str,
-        help="The locale to use when generating data",  # see available locales here (https://faker.readthedocs.io/en/master/locales.html)
+        help="The locale to use when generating data",
+        # see available locales here (https://faker.readthedocs.io/en/master/locales.html)
     )
 
     args = parser.parse_args()
@@ -376,12 +379,15 @@ def generate_pdf():
             patients.last_name AS patient_last_name,
             patients.dob AS patient_birth_date,
             patients.weight AS patient_weight,
+            d_icd_diagnoses.short_title AS diagnoses_st,
+            d_icd_diagnoses.long_title AS diagnoses_lt,
             documents.document as path,
             documents.type as type,
             documents.hadm_id as hadm_id
         FROM documents
         JOIN caregivers ON documents.cgid = caregivers.cgid
-        JOIN patients ON documents.patient_id = patients.subject_id"""
+        JOIN patients ON documents.patient_id = patients.subject_id
+        JOIN diagnoses_icd ON documents.patient_id = diagnoses_icd.subject_id JOIN d_icd_diagnoses ON diagnoses_icd.icd9_code = d_icd_diagnoses.icd9_code"""
     )
 
     for row in tqdm(result, desc="Generating PDF prescriptions from database"):
@@ -394,12 +400,12 @@ def generate_pdf():
                 row["patient_birth_date"], "%Y-%m-%d %H:%M:%S"
             )
             patient_age = (
-                doc_date.year
-                - patient_birth_date.year
-                - (
-                    (doc_date.month, doc_date.day)
-                    < (patient_birth_date.month, patient_birth_date.day)
-                )
+                    doc_date.year
+                    - patient_birth_date.year
+                    - (
+                            (doc_date.month, doc_date.day)
+                            < (patient_birth_date.month, patient_birth_date.day)
+                    )
             )
             medication_result = connection.execute(
                 f"""SELECT
@@ -423,17 +429,39 @@ def generate_pdf():
                         "poso_type": medic["poso_type"],
                     }
                 )
-
-        prescription_generator(
-            row["path"],
-            locale=args.locale,
-            doc_attributes={"date": doc_date.strftime("%d/%m/%Y")},
-            doctor={"first_name": row["doctor_first_name"], "last_name": row["doctor_last_name"],},
-            patient={
-                "first_name": row["patient_first_name"],
-                "last_name": row["patient_last_name"],
-                "age": patient_age,
-                "weight": row["patient_weight"],
-            },
-            medication=medication,
-        )
+        if row["type"] == "prescription":
+            prescription_generator(
+                row["path"],
+                locale=args.locale,
+                doc_attributes={"date": doc_date.strftime("%d/%m/%Y")},
+                doctor={"first_name": row["doctor_first_name"], "last_name": row["doctor_last_name"], },
+                patient={
+                    "first_name": row["patient_first_name"],
+                    "last_name": row["patient_last_name"],
+                    "age": patient_age,
+                    "weight": row["patient_weight"],
+                },
+                medication=medication,
+            )
+        elif row["type"] == "report":
+            cr_generator(
+                row["path"],
+                locale=args.locale,
+                doctor={"first_name": row["doctor_first_name"], "last_name": row["doctor_last_name"], },
+                patient={
+                    "first_name": row["patient_first_name"],
+                    "last_name": row["patient_last_name"],
+                    "age": patient_age,
+                    "weight": row["patient_weight"],
+                },
+                hospitalization={
+                    "reason": row["diagnoses_st"],
+                    "hospitalization": row["diagnoses_lt"]
+                },
+                date={
+                    "last_date": doc_date.strftime("%d/%m/%Y"),
+                    "first_date": (doc_date - datetime.timedelta(days=randint(0, 16))).strftime("%d/%m/%Y"),
+                    "birth_date": patient_birth_date
+                },
+                medication=medication,
+            )
\ No newline at end of file
