@@ -145,7 +145,7 @@ HOSP = [["ischémie de main droite","L intervention a consisté en une ligature
              ["tentative de désobstruction IVA","La procédure a consisté en une tentative de recanalisation de l IVA avec échec"],
              ["pontage aorto coronaire", "L intervention consiste en un double pontage IVA"],
              ["artériographie des membres inférieurs", "L artériographie retrouve une arthrite distale sévère"],
-             ["faux anévrisme de l aorte ascendante", "Le suivi scanographique a montré l apparition d un aspect d'un double faux anévrisme de l aorte initiale"]]
+             ["faux anévrisme de l aorte ascendante", "Le suivi scanographique a montré l apparition d un aspect d un double faux anévrisme de l aorte initiale"]]
 
 ANT = ["fumeur",
        "hypertension artérielle",
@@ -463,12 +463,13 @@ def cr_generator(output_path, locale="fr_FR", **kwargs):
     for _ in range(nb_ant):
         field_group_values["antecedent"].append(choice(ANT))
 
-    for group_name in {'doc_attributes', 'medical_centre', 'doctor', 'patient', "hospitalization"}:
+    for group_name in {'doc_attributes', 'medical_centre', 'doctor', 'patient', "hospitalization", "date"}:
         for field_name in field_group_values[group_name]:
             try:
                 field_group_values[group_name][field_name] = kwargs[group_name][
                     field_name
                 ]
+
             except KeyError:
                 pass
 
@@ -491,19 +492,21 @@ def cr_generator(output_path, locale="fr_FR", **kwargs):
     for group_name, group_values in kwargs.items():
         if not group_name in field_group_values:
             print(f"Attributes group '{group_name}' is not recognized.")
-        elif group_name in {'doc_attributes', 'medical_centre', 'doctor', 'patient'}:
+        elif group_name in {'doc_attributes', 'medical_centre', 'doctor', 'patient', 'date', 'hospitalization'}:
             for field_name in group_values.keys():
                 if not field_name in field_group_values[group_name]:
                     print(
                         f"Attribute '{field_name}'' from group '{group_name}' is not recognized."
                     )
+        elif group_name == 'antecedent':
+            pass
         else:
             assert group_name == 'medication', f"Unexpected argument."
             assert type(kwargs[
                             "medication"]) == list, f"Wrong argument type : 'medication' argument must be a list of dictionnaries."
             for i in range(nb_medics):
                 for field_name in kwargs["medication"][i].keys():
-                    if not field_name in field_group_values['medications'][i].keys():
+                    if not field_name in field_group_values['medication'][i].keys():
                         print(
                             f"Attribute '{field_name}' from medication #{i} is not recognized."
                         )
@@ -677,4 +680,4 @@ def generate(nb, output_path):
 
     link.to_csv(output_path / "index.csv")
 
-    print("Generation terminated !")
+    print("Generation terminated !")
\ No newline at end of file
